@@ -10,7 +10,7 @@ use parent qw{ Astro::App::Satpass2::ParseTime::Date::Manip };
 
 use Astro::App::Satpass2::Utils qw{ load_package @CARP_NOT };
 
-our $VERSION = '0.042';
+our $VERSION = '0.042_01';
 
 my $invalid;
 
@@ -30,7 +30,7 @@ my ( $default_zone ) = eval {
     grep { m{ \A TZ= }smx } Date_Init()
 };
 
-my $epoch_offset = time_gm( 0, 0, 0, 1, 0, 70 );
+my $epoch_offset = time_gm( 0, 0, 0, 1, 0, 1970 );
 
 sub delegate {
     return __PACKAGE__;
@@ -41,7 +41,9 @@ sub parse_time_absolute {
     $invalid and $self->wail( $invalid );
     my $time = UnixDate( $string, '%s' ) - $epoch_offset;
     if ( $self->perltime() ) {
-	$time = time_local( gmtime $time );
+	my @gt = gmtime $time;
+	$gt[5] += 1900;
+	$time = time_local( @gt );
     }
     return $time;
 }
@@ -110,7 +112,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2019 by Thomas R. Wyant, III
+Copyright (C) 2009-2020 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
